import aiohttp
import re
from typing import Optional, Tuple, Union
from .api_base import ApiEnv, ApiEncoder, ApiInfo, ApiInvoker
from .bilibili_encoder import WbiEncoder
from .bv2av import bv2av, av2bv

URL_REGEXPS = {
    'SHORT_URL': re.compile(r'(^|(?<=\W))https?://b23\.tv/(?P<id>[a-zA-Z0-9]+)'),
    'LONG_URL': re.compile(r'(^|(?<=\W))https?://(?:www\.|m\.)?bilibili\.com/video/(?P<id>av[0-9]+|BV[0-9a-zA-Z]+)'),
    'BV_CODE': re.compile(r'(^)(?P<id>BV[0-9a-zA-Z]{5,15})($)'),
}

class BilibiliApis(ApiEnv):
    """B 站 API 集合"""

    def __init__(
            self,
            ua: Optional[str] = None,
            refer: Optional[str] = None,
            cookie: Optional[str] = None,
        ):
        ua = ua or 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.3'
        refer = refer or 'https://www.bilibili.com/'
        cookie = cookie or ''
        super().__init__(ua=ua, refer=refer, cookie=cookie)
        # print('BilibiliApis initialized with cookie:', self.cookie)

    def set_cookie(self, cookie: str):
        self.cookie = cookie
        if hasattr(self, '_encoder'):
            delattr(self, '_encoder')
        # print('BilibiliApis cookie updated to:', self.cookie)

    def get_encoder(self) -> ApiEncoder:
        if not hasattr(self, '_encoder'):
            # print('Creating new WbiEncoder with cookie:', self.cookie)
            self._encoder = WbiEncoder(
                ua=self.ua,
                refer=self.refer,
                cookie=self.cookie,
            )
        return self._encoder

    def check_result(self, result: dict) -> Tuple[bool, str]:
        code = result.get('code', -1)
        if code == 0:
            return True, '成功'
        msg = result.get('message', '未知错误')
        return False, msg
    
    def bv2av(self, bvid: str) -> int:
        'BV 号转 AV 号'
        return bv2av(bvid)

    def av2bv(self, aid: int) -> str:
        'AV 号转 BV 号'
        return av2bv(aid)

    def get_url_from_text(self, text: str):
        '从文本中提取 BV 号或 AV 号链接'
        url: Optional[str] = None
        for key, regexp in URL_REGEXPS.items():
            m = regexp.search(text)
            if not m: continue
            url = m.group(0) if m and len(m.groups()) >= 1 else None
            if key.endswith('_CODE'):
                url = f"https://b23.tv/{url}"
            break
        return url

    async def get_id_from_url(self, url: str):
        '从 URL 中提取 BV 号或 AV 号'
        matched = None
        for regexp in URL_REGEXPS.values():
            m = regexp.match(url)
            if not m: continue
            matched = m
        # print(f'get_id_from_url: matched={matched}, groups length={len(matched.groups()) if matched else 0}')
        # 取出 ID 部分
        dict = matched.groupdict() if matched else {}
        id_str = dict.get("id", None) if dict else None
        if not matched or not id_str:
            return None
        # 判断是 BV 号还是 AV 号
        type = id_str[:2].lower()
        id = id_str[2:]
        print(f'get_id_from_url: type={type}, id={id}')
        if type == 'av' and id.isdigit():
            aid = int(id)
            bvid = av2bv(aid)
            return {
                'av': aid,
                'bv': bvid
            }
        elif type == 'bv' and re.match(r'^[0-9a-zA-Z]+$', id):
            bvid = id_str
            aid = bv2av(bvid)
            return {
                'av': aid,
                'bv': bvid
            }
        elif re.match(r'^https://b23.tv/', url):
            # 短链，无法直接判断，根据请求后重定向的 location 来判断
            try:
                async with aiohttp.ClientSession() as session:
                    async with session.head(url, allow_redirects=True, timeout=10) as resp:
                        final_url = str(resp.url)
                # print(f'get_id_from_url: 短链重定向到 {final_url}')
                return await self.get_id_from_url(final_url)
            except Exception as e:
                print(f'get_id_from_url: 无法解析短链 {url}: {e}')
        return None

    def video_info_api(self, aid: Optional[int]=None, bvid: Optional[str]=None) -> ApiInvoker:
        '获取指定 bvid 的视频信息'
        'https://github.com/SocialSisterYi/bilibili-API-collect/blob/47be3f206fc5d8a92fa81886eb507e4492e4e27a/docs/video/info.md'
        url = 'https://api.bilibili.com/x/web-interface/view'
        params = {
            'aid': aid if aid else '',
            'bvid': bvid if bvid else '',
        }
        errors = {
            '0': '成功',
            '-400': '请求错误',
            '-403': '权限不足',
            '-404': '视频不存在',
            '62002': '稿件不可见',
            '62004': '稿件审核中',
            '62012': '仅UP主可见',
        }
        return ApiInvoker(
            self,
            ApiInfo(url, params, errors, encoder=None),
        )

    def get_comments_api(self, oid: str, type: int, next_offset: str) -> ApiInvoker:
        '获取指定 oid 的评论列表'
        'https://github.com/SocialSisterYi/bilibili-API-collect/blob/60a0c5d1a2f44fe61335da04571305fa7727a968/docs/comment/list.md'
        url = 'https://api.bilibili.com/x/v2/reply/wbi/main'
        params = {
            'oid': oid,
            'type': type,
            'mode': 3,
            'pagination_str': f'{{"offset":"{next_offset}"}}' if next_offset else '',
            'plat': 1,
            'seek_rpid': '',
            'web_location': 1315875,
        }
        errors = {
            '0': '成功',
            '-400': '请求错误',
            '-404': '无此项',
            '12002': '评论区已关闭',
            '12009': '评论主体的 type 不合法',
        }
        return ApiInvoker(
            self,
            ApiInfo(url, params, errors, encoder=self.get_encoder()),
        )



import aiohttp
import asyncio
import json
import os
import re

from typing import Literal
from nonebot import get_driver, logger, on_message, on_regex
from nonebot_plugin_htmlrender import get_new_page
from nonebot_plugin_localstore import get_cache_dir, get_config_file
from nonebot.adapters.onebot.v11 import Event, Message, MessageSegment
from nonebot.matcher import Matcher
from aiohttp import web

from ..modules.bilibili_apis import BilibiliApis
from ..modules.bilibili_api_host import get_app
from ..modules.browser_adapter import BrowserMode
from ..config import config

driver = get_driver()

# 通用配置从 envConfig 读取
envConfig = get_driver().config
SUPERUSERS = list(envConfig.superusers)

# 插件配置从 config 读取
whitelist = config.analysis_whitelist
group_whitelist = config.analysis_group_whitelist
blacklist = config.analysis_blacklist
group_blacklist = config.analysis_group_blacklist
group_strategies = config.analysis_group_strategies

bili_helper_tmp_dir= get_cache_dir("bili_helper")

cookie_store_name = "cookie_store.json"
cookie_store_path = get_config_file("bili_helper", cookie_store_name)
def write_cookie(config: dict):
    try:
        with open(cookie_store_path, "w") as f:
            json.dump(config, f, ensure_ascii=False, indent=4)
        logger.info('配置 {} 写入成功'.format(cookie_store_name))
        return True
    except Exception as e:
        logger.info('配置 {} 写入失败: {}'.format(cookie_store_name, e))
        return False
    
def read_cookie():
    config = { 'value': '' }
    try:
        with open(cookie_store_path, "r") as f:
            config = json.load(f)
        logger.info('配置 {} 读取成功'.format(cookie_store_name))
    except Exception as e:
        logger.info('配置 {} 为空或格式有误: {}'.format(cookie_store_name, e))
        logger.info('准备创建默认配置...')
        write_cookie(config)
    return config

cookie_store = read_cookie()
# print('Loaded cookie:', cookie_store)

# 启动API服务
bili_helper_port = 9528
api_web = get_app(
    BrowserMode.NONEBOT_HTMLRENDER,
    cookie = cookie_store.get('value', ''),
)
api_web_runner = web.AppRunner(api_web.app)

@driver.on_startup
async def start_bili_helper_server():
    await api_web_runner.setup()
    site = web.TCPSite(api_web_runner, '127.0.0.1', bili_helper_port)
    await site.start()
    logger.info(f'BiliBili Helper API started at http://127.0.0.1:{bili_helper_port}')

@driver.on_shutdown
async def shutdown_bili_helper_server():
    await api_web_runner.cleanup()

bili_apis = BilibiliApis(
    cookie = cookie_store.get('value', ''),
)

def get_group_id(event: Event) -> str:
    return str(
        getattr(event, "group_id", None)
        if hasattr(event, "group_id")
        else getattr(event, "channel_id", None)
        if hasattr(event, "channel_id")
        else None
    )

async def is_allowed(event: Event) -> bool:
    user_id = str(event.get_user_id())
    group_id = get_group_id(event)

    if user_id in whitelist or group_id in group_whitelist:
        return True

    if len(whitelist) > 0 or len(group_whitelist) > 0:
        return False

    if user_id in blacklist or group_id in group_blacklist:
        return False

    return True

analysis_bili = on_message(
    rule=is_allowed,
    block=False,
    priority=8,
)

@analysis_bili.handle()
async def handle_analysis(event: Event, matcher: Matcher) -> None:

    async def fallback_bili_url(url: str, matcher: Matcher):
        await matcher.send(f"检测到B站链接: {url}")
        matcher.stop_propagation()

    message = event.get_message()
    bili_url = None
    mode: Literal["detail+comments", "link+comments", None] = None

    # 先在小程序段里找
    for seg in message:
        if (seg.type == "json"):
            json_str = str(seg.data.get("data", {}))
            data = json.loads(json_str)

            app = data.get("app", "")
            meta = data.get("meta", {})
            if re.match(r"^com\.tencent\.miniapp(_|\.|$)", app):
                detail = None
                for k, v in meta.items():
                    if k.startswith("detail_"):
                        detail = v
                        break
                if not detail:
                    return
                url = detail.get("qqdocurl", "")
                logger.info(f"解析到小程序链接: {url}")
                if not url or not re.match(r"^https?://b23\.tv", url):
                    return
                bili_url = url
                mode = "link+comments"
                break
            if re.match(r"^com\.tencent\.tuwen(\.|$)", app):
                news = meta.get("news", {})
                url = news.get("jumpUrl", "")
                logger.info(f"解析到图文链接: {url}")
                if not url or not re.match(r"^https?://b23\.tv", url):
                    return
                bili_url = url
                mode = "detail+comments"
                break

    # 如果没有在小程序里找到，就在纯文本里找
    if not bili_url:
        text = event.get_plaintext().strip()
        bili_url = bili_apis.get_url_from_text(text)
        if bili_url:
            mode = 'detail+comments'

    # 如果还是没有找到，就直接返回
    if not bili_url:
        return

    is_info_sent = False
    try:
        mode_str = str(mode)
        matcher.stop_propagation()
        group_id = get_group_id(event)
        strategy = group_strategies.get(group_id, None)
        def is_mode_allowed(m: str) -> bool:
            if not strategy:
                return True
            return m in strategy
        # url = quote(bili_url)
        vids = await bili_apis.get_id_from_url(bili_url)
        if not vids:
            logger.warning(f"无法从链接中提取ID: {bili_url}")
            return
        logger.debug(f"提取到的ID: {vids}")
        bvid = vids.get("bv", "") if vids else ""
        info = await bili_apis.video_info_api(bvid=bvid).call()
        info_data = info.get("data", {})
        if is_mode_allowed("detail") and "detail" in mode_str:
            def number_readable(num: int) -> str:
                if num >= 1_0000_0000: return f"{num / 1_0000_0000:.1f}亿"
                elif num >= 1_0000: return f"{num / 1_0000:.1f}万"
                else: return str(num)

            def format_duration(seconds: int) -> str:
                if seconds < 60:
                    return f"00:{seconds:02d}"
                elif seconds < 3600:
                    minutes = seconds // 60
                    seconds = seconds % 60
                    return f"{minutes:02d}:{seconds:02d}"
                else:
                    hours = seconds // 3600
                    minutes = (seconds % 3600) // 60
                    seconds = seconds % 60
                    return f"{hours}:{minutes:02d}:{seconds:02d}"

            title = info_data.get("title", "未知标题")
            cover_url = info_data.get("pic", "")
            artist = info_data.get("owner", {}).get("name", "未知作者")
            type_name = info_data.get("tname", "未知分区")
            stat = info_data.get("stat", {})
            play_count = number_readable(stat.get("view", 0))
            # danmaku_count = number_readable(stat.get("danmaku", 0))
            like_count = number_readable(stat.get("like", 0))
            coin_count = number_readable(stat.get("coin", 0))
            # favorite_count = number_readable(stat.get("favorite", 0))
            duration = format_duration(info_data.get("duration", 0))
            desc = info_data.get("desc", "")

            msg_seg = [
                MessageSegment.text(f'{title}\n')
            ]

            try:
                if cover_url:
                    async with aiohttp.ClientSession() as session:
                        async with session.get(cover_url, timeout=10) as resp:
                            cover_img = await resp.read()
                            msg_seg.append(MessageSegment.image(cover_img))
            except Exception as e:
                logger.warning(f"获取封面失败: {e}")

            info_text = f"👤 {artist}\n" \
                        f"🔖 {type_name}  📼 {duration}\n" \
                        f"▶️ {play_count}  👍 {like_count}  🪙 {coin_count}"
            msg_seg.append(MessageSegment.text(info_text))

            if desc:
                if len(desc) > 300:
                    desc = desc[:300] + "..."
                desc_lines = desc.splitlines()
                if len(desc_lines) > 3:
                    desc = "\n".join(desc_lines[:3]).rstrip("...") + "..."
                msg_seg.append(MessageSegment.text(f"\nℹ️ {desc}"))
            await matcher.send(Message(msg_seg))
            is_info_sent = True
        if is_mode_allowed("link") and "link" in mode_str:
            bvid = info_data.get("bvid", "")
            new_url = f"https://b23.tv/{bvid}" if bvid else bili_url
            await matcher.send(f"解析到B站链接: {new_url}")
            is_info_sent = True
        if is_mode_allowed("comments") and "comments" in mode_str:
            tmp_name = f"{int(event.time)}_{event.get_session_id()}"
            url = f'http://127.0.0.1:{bili_helper_port}/render/comments?bvid={info_data.get("bvid","")}'
            result = None
            async with aiohttp.ClientSession() as session:
                async with session.get(url, timeout=20) as resp:
                    resp_text = await resp.text()
                    result = json.loads(resp_text)
            if result.get("code", -1) != 0:
                raise Exception(f"获取评论失败: {result.get('message', '未知错误')}")
            data = result.get("data", {})

            comments_html = data.get("html", "")
            comments_path = os.path.join(bili_helper_tmp_dir, f"{tmp_name}.html")
            with open(comments_path, "w", encoding="utf-8") as f:
                f.write(comments_html)
            logger.info(f"评论页已保存到 {comments_path}")
            async with get_new_page(
                device_scale_factor=1.0,
            ) as page:
                comments_full_path = os.path.abspath(comments_path)
                await page.goto("file://" + comments_full_path)
                await page.wait_for_load_state("networkidle")
                comments_img_path = os.path.join(bili_helper_tmp_dir, f"{tmp_name}.jpg")
                await page.screenshot(path=comments_img_path, full_page=True, type="jpeg", quality=80)
                logger.info(f"评论截图已保存到 {comments_img_path}")
                comments_img = open(comments_img_path, "rb").read()
                meg = Message(MessageSegment.image(comments_img))
                await matcher.send(meg)
                # 清理临时文件
                os.remove(comments_path)
                os.remove(comments_img_path)
    except Exception as e:
        logger.error(f"处理B站链接失败: {e}")
        if is_mode_allowed("link") and "link" in mode_str and not is_info_sent:
            await fallback_bili_url(bili_url, matcher)
    pass

set_cookie_pattern = rf"^设置B站Cookie\s*(.+)?$"
set_cookie_sniffer = on_regex(set_cookie_pattern, flags=re.DOTALL, priority=5, block=True)
@set_cookie_sniffer.handle()
async def handle_set_cookie(event: Event, matcher: Matcher) -> None:
    user_id = str(event.get_user_id())
    if not user_id in SUPERUSERS:
        return
    text = event.get_plaintext().strip()
    m = re.match(set_cookie_pattern, text, flags=re.DOTALL)
    if not m:
        return
    cookie_value = m.group(1).strip() if m.group(1) else ""
    if not cookie_value:
        await matcher.send("请提供Cookie内容")
        return
    cookie_store['value'] = cookie_value
    write_cookie(cookie_store)
    bili_apis.set_cookie(cookie_value)
    api_web.set_cookie(cookie_value)
    await matcher.send("B站Cookie已更新")



import aiohttp
import asyncio
import json
import os
from pathlib import Path
import sys

from aiohttp import web

# 添加父目录到 Python 路径
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

from modules.bilibili_apis import BilibiliApis 
from modules.bilibili_api_host import get_app
from modules.browser_adapter import BrowserAdapter, BrowserMode

DIRECTORY = os.path.dirname(os.path.abspath(__file__))
ROOT_DIR = os.path.dirname(DIRECTORY)
TMP_DIR = os.path.join(ROOT_DIR, 'tmp')

os.makedirs(TMP_DIR, exist_ok=True)

class Counter:
    def __init__(self, name=''):
        self.count = 0
        self.name = name

    def next(self):
        self.count += 1
        return f'{self.name}_{self.count}'

async def test_host():
    port = 8078
    browser_adapter = BrowserAdapter(mode=BrowserMode.PLAYWRIGHT)
    
    api_web = get_app(browser_mode=BrowserMode.PLAYWRIGHT)
    runner = web.AppRunner(api_web.app)
    await runner.setup()
    site = web.TCPSite(runner, '127.0.0.1', port)
    
    try:
        await site.start()
        print(f'Bilibili 助手服务已启动 on http://127.0.0.1:{port}')

        # 测试逻辑
        url = f'http://127.0.0.1:{port}/render/comments?bvid=BV1tuadziEef'
        print(f'- 测试渲染评论: {url}')
        
        loop = asyncio.get_running_loop()
        async with aiohttp.ClientSession() as session:
            async with session.get(url, timeout=60) as response:
                response.raise_for_status()
                result = await response.json()
                code = result.get('code', -1)
                msg = result.get('message', '')
        if code != 0:
            print(f'- Render comments error: {code} {msg}')
            return
        data = result.get('data', {})
        rendered_html = data.get('html', '')
        html_file = Path(TMP_DIR) / f'comment.html'
        with open(html_file, 'w', encoding='utf-8') as f:
            f.write(rendered_html)
        print(f'- Rendered comments saved to {html_file}')
        file_url = f'file://{html_file.absolute()}'
        print(f'- Open file URL: {file_url}')
        async with browser_adapter.get_new_page(
            viewport={'width': 800, 'height': 600},
        ) as page:
            print('- Navigating to page...')
            await page.goto(file_url)
            await page.wait_for_load_state("networkidle")
            screenshot = await page.screenshot(full_page=True, type='jpeg')
            shot_file = Path(TMP_DIR) / f'comment.jpg'
            with open(shot_file, 'wb') as f:
                f.write(screenshot)
            print(f'- Screenshot saved to {shot_file}')

    except Exception as e:
        print('- Request error:', e)
    finally:
        await runner.cleanup()
        print('Bilibili 助手服务已停止')

async def test_api():
    cookie_json_path = Path(ROOT_DIR) / '../../data' / 'bili_helper_cookie.json'
    cookie_value = ''
    if cookie_json_path.exists():
        with open(cookie_json_path, 'r', encoding='utf-8') as f:
            try:
                cookie_data = json.load(f)
                cookie_value = cookie_data.get('value', '')
                print('Loaded cookie value:', cookie_value)
            except Exception as e:
                print('Failed to load cookie JSON:', e)
    else:
        print('Cookie JSON file does not exist:', cookie_json_path)
    api = BilibiliApis(
        cookie=cookie_value,
    )
    response = await api.get_comments_api(
        oid='115256957471455',
        type=1,
        next_offset='',
    ).call()
    # response = api.videoInfoApi(
    #     bvid='BV1YaJDzAEGP',
    # ).call()
    print(json.dumps(response, ensure_ascii=False, indent=2))

# === 主函数入口 ===

async def main():
    await test_api()
    # await test_host()

if __name__ == '__main__':
    asyncio.run(main())



# import asyncio
from aiohttp import web
import json
import os
from pathlib import Path

from .bilibili_apis import BilibiliApis
from .browser_adapter import BrowserAdapter, BrowserMode

DIRECTORY = os.path.dirname(os.path.abspath(__file__))
ROOT_DIR = os.path.dirname(DIRECTORY)
WEB_DIR = os.path.join(ROOT_DIR, 'resources')
MOCK_DIC = os.path.join(WEB_DIR, 'mocks')

def get_app(
        browser_mode: BrowserMode=BrowserMode.NONEBOT_HTMLRENDER,
        cookie: str = '',
):
    bilibili_apis = BilibiliApis(cookie=cookie)
    browser_adapter = BrowserAdapter(mode=browser_mode)

    async def api_mock(request):
        """
        返回模拟数据的接口示例
        GET /mock?t=example
        """
        t = request.query.get('t', '')
        mock_file = Path(MOCK_DIC) / f'{t}.json'
        if not mock_file.is_file():
            return web.Response(status=404, text='Mock file does not exist.')
        with open(mock_file, 'r', encoding='utf-8') as f:
            payload = json.load(f)
        # web.json_response 会自动设置 Content-Type: application/json
        return web.json_response(payload)

    async def bvid2aid(request):
        """
        B站BV号转AV号接口
        GET /bvid2aid?bvid=BV1xx411c7mD
        返回示例:
        {
            "bvid": "BV1xx411c7mD",
            "aid": 170001
        }
        """
        bvid = request.query.get('bvid', '')
        if not bvid.startswith('BV'):
            return web.json_response({'error': 'Invalid BVID'}, status=400)
        try:
            aid = bilibili_apis.bv2av(bvid)
            return web.json_response({'bvid': bvid, 'aid': aid})
        except Exception as e:
            return web.json_response({'error': str(e)}, status=500)

    async def aid2bvid(request):
        """
        B站AV号转BV号接口
        GET /aid2bvid?aid=170001
        返回示例:
        {
            "aid": 170001,
            "bvid": "BV1xx411c7mD"
        }
        """
        aid_str = request.query.get('aid', '')
        if not aid_str.isdigit():
            return web.json_response({'error': 'Invalid AID'}, status=400)
        aid = int(aid_str)
        try:
            bvid = bilibili_apis.av2bv(aid)
            return web.json_response({'aid': aid, 'bvid': bvid})
        except Exception as e:
            return web.json_response({'error': str(e)}, status=500)

    async def video_info(request):
        """
        获取视频信息接口
        GET /video_info?bvid=BV1xx411c7mD
        或
        GET /video_info?aid=170001
        返回示例:
        {
            "code": 0,
            "message": "成功",
            "data": { ... }
        }
        """
        bvid = request.query.get('bvid', '')
        aid_str = request.query.get('aid', '')
        aid = int(aid_str) if aid_str.isdigit() else None
        if not bvid and not aid:
            return web.json_response({'error': 'Must provide either BVID or AID'}, status=400)
        try:
            api_invoker = bilibili_apis.video_info_api(aid=aid, bvid=bvid)
            result = await api_invoker.call()
            return web.json_response(result)
        except Exception as e:
            return web.json_response({'error': str(e)}, status=500)

    async def comments(request):
        """
        获取视频评论接口
        GET /comments?oid=123456&type=1&next_offset=
        参数:
        - oid: 视频的AV号或BV号对应的数字ID
        - type: 评论类型, 1表示视频
        - next_offset: 分页参数, 初始为空
        返回示例:
        {
            "code": 0,
            "message": "成功",
            "data": { ... }
        }
        """
        oid = request.query.get('oid', '')
        type_str = request.query.get('type', '1')
        next_offset = request.query.get('next_offset', '')
        if not oid.isdigit() or not type_str.isdigit():
            return web.json_response({'error': 'Invalid oid or type'}, status=400)
        type = int(type_str)
        try:
            api_invoker = bilibili_apis.get_comments_api(oid=oid, type=type, next_offset=next_offset)
            result = await api_invoker.call()
            return web.json_response(result)
        except Exception as e:
            return web.json_response({'error': str(e)}, status=500)

    async def render_comments(request):
        """
        渲染评论的HTML页面
        GET /render/comments?bvid=BV1xx411c7mD
        """
        bvid = request.query.get('bvid', '')
        if not bvid.startswith('BV'):
            return web.Response(status=400, text='Invalid BVID')
        try:
            url = f'http://{request.host}/resources/render/bilibili/comment.html?bvid={bvid}'
            print('- Page URL:', url)
            async with browser_adapter.get_new_page() as page:
                print('- Navigating to page...')
                await page.goto(url)
                await page.wait_for_load_state("networkidle")
                # print('- Page content:', await page.content())
                rendered_result = await page.evaluate('document.getElementById("rendered-result")?.textContent || ""')
                rendered_html = await page.evaluate('document.getElementById("rendered-html")?.textContent || ""')
                print('- Rendered Result:', rendered_result)
                result = json.loads(rendered_result) if rendered_result else {}
                # 如果 result 没有 code 字段，补充一个
                if 'code' not in result:
                    result['code'] = -1
                if 'message' not in result:
                    result['message'] = '未知错误'
                if result.get('code') != 0:
                    return web.json_response(result)
                # file_url = f'file://{html_file}'
                # await page.goto(file_url)
                # await page.wait_for_load_state("networkidle")
                # screenshot = await page.screenshot(full_page=True, type='jpeg')
                # return web.Response(body=screenshot, content_type='image/jpeg')
                return web.json_response({
                    'code': 0,
                    'message': '成功',
                    'data': {
                        'html': rendered_html,
                    },
                })

        except Exception as e:
            print('- Render comments error:', e)
            return web.Response(status=500, text=str(e))

    from aiohttp.web_request import Request
    from aiohttp.typedefs import Handler

    @web.middleware
    async def cors_middleware(request: Request, handler: Handler):
        """
        为静态资源添加 CORS 头的中间件
        """
        response = await handler(request)
        # print(f"Request path: {request.path}")
        if request.path.startswith('/resources/font/'):
            response.headers['Access-Control-Allow-Origin'] = '*'
        return response

    app = web.Application(
        middlewares=[cors_middleware],
    )

    app.router.add_static('/resources/', path=WEB_DIR, name='resource', show_index=True)
    app.router.add_get('/mock', api_mock)
    app.router.add_get('/bvid2aid', bvid2aid)
    app.router.add_get('/aid2bvid', aid2bvid)
    app.router.add_get('/video_info', video_info)
    app.router.add_get('/comments', comments)
    app.router.add_get('/render/comments', render_comments)

    class WrappedApp:
        def __init__(self, app, set_cookie_func):
            self.app = app
            self._set_cookie = set_cookie_func

        def set_cookie(self, cookie: str):
            self._set_cookie(cookie)

    return WrappedApp(
        app=app,
        set_cookie_func=bilibili_apis.set_cookie,
    )
